{ config, pkgs, ... }:
{
  users.users.yoda = {
    packages = with pkgs; [
      #
      # DEVELOPMENT
      #

      # CLI apps
      gnumake # make
      wget
      killall

      # Graphical apps
      meld # Diff and merge tool
      # Rip DVD and Blu-ray; rotate and export videos.
      # Requires gstreamer with plugins to preview encoded video.
      #   nix-shell -p gstreamer.nix
      #   ghb
      handbrake
      mediainfo-gui # View video metadata
      mkvtoolnix # Split or merge video, audio and subtitle files
      avidemux # Basic video editing without conversion
      identity # Comparing multiple versions of an image or video
      obs-studio # Video recording and live streaming.
      # obs-studio-plugins.obs-vaapi # gstreammer based VAAPI for H.264, H.265 and AV1 encoding. On some AMD hardware this may perform bettern than FFmpeg VAAPI.
      gnome.gnome-disk-utility # Partition and format disks. Mount disk images (.ISO)
      gnome.gnome-calculator

      fractal # Matrix chat client.
      # Other Matrix clients.
      #   fluffychat
      #   Web version: https://app.cinny.in/
      #   cinny-desktop
      #   element-desktop, see `element-desktop.nix`

      #
      # 3D modeling and printing
      #

      # Can import .stl files: https://docs.blender.org/manual/en/latest/files/import_export/stl.html
      #blender
      # Optional HIP support increases the closure size significantly (https://github.com/NixOS/nixpkgs/blob/34bdaaf1f0b7fb6d9091472edc968ff10a8c2857/pkgs/applications/misc/blender/default.nix#L9).
      # Blender HIP rendering: https://docs.blender.org/manual/en/latest/render/cycles/gpu_rendering.html#hip-amd
      #blender-hip

      # General purpose Open Source 3D CAD/MCAD/CAx/CAE/PLM modeler.
      # Can import .stl files.
      #freecad
      # 3D parametric model compiler.
      # Can import .stl files with: import("example.stl");
      #openscad

      # G-code generator for 3D printers.
      # Multiple G-code flavors supported (RepRap, Makerbot, Mach3, Machinekit, etc.)
      # SuperSlicer is a PrusaSlicer fork (which is a slic3r fork) (previously Slic3r++).
      #super-slicer

      #
      # OFFICE
      #

      # Graphical apps

      junction # Choose the application to open a specific file type or URI.
      epiphany # Web browser
      tartube-yt-dlp # Video downloader (front-end for yt-dlp)
      rnote # Handwritten notes
      xournalpp # Handwritte notes
      pdfarranger # PDF files: Split, merge, rotate, rearrange, export selected pages
      # Office suite.
      # For spellcheck, see here: https://nixos.wiki/wiki/LibreOffice#Spellcheck
      libreoffice-fresh
      zotero # Collect, organize, cite, and share your research sources
      anki-bin # Flashcards. TODO: export ANKI_WAYLAND=1
      transmission-gtk # BitTorrent client
      gnome-solanum  # Pomodoro timer
      gnome.gnome-contacts # Contacts
      gnome.gnome-calendar # Calendar
      unstable.planify # Tasks
      #unstable.errands # Tasks
      jameica # Hibiscus plugin -> HBCI online banking. Sparkasse-Nürnberg https://www.willuhn.de/wiki/doku.php?id=support:list:banken:spk#nuernberg.
      picard # Music tagger by MusicBrainz
    ];
  };
}
